<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX naudotojų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administravimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Pridėti naują naudotoją</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Pridėti naudotojo paskyrą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Įveskite naujo naudotojo slaptažodį</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>slaptažodis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Iš naujo įveskite naujo naudotojo slaptažodį</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>patvirtinkite slaptažodį</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Naujo naudotojo naudotojo vardas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Naudotojo prisijungimo vardas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Įveskite naudotojo vardą naujam naudotojui</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>naudotojo_vardas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>Naujo naudotojo slaptažodis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Patvirtinkite naudotojo slaptažodį:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Naudotojo slaptažodis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Ištrinti naudotojo paskyrą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Pasirinkite naudotoją, kurį ištrinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>Naudotojas, kurį ištrinti:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Taip pat ištrinti naudotojo namų katalogą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Ištrinti naudotojo namų katalogą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Pervadinti naudotojo paskyrą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Pasirinkite naudotoją, kurį keisti:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Naujas naudotojo vardas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Pakeisti naudotojo slaptažodį</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>naujas slaptažodis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Patvirtinkite naują slaptažodį:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>patvirtinkite naują slaptažodį</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Naujas naudotojo slaptažodis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Parametrai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Pataisyti naudotojo konfigūraciją</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Modifikuoti naudotojo paskyrą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Pasirinkite naudotoją, kurį pataisyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>Naudotojas, kurį keisti:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Atkurti numatytąsias reikšmes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Atkurti naršyklės konfigūracijas į MX numatytąsias</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Mozilla (Iceweasel ar Firefox) konfigūracijos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Pakeisti automatinio prisijungimo nustatymus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Prisijungti automatiškai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Norint prisijungti, reikalauti slaptažodžio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Kopijavimas/Sinchronizavimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Kopijuoti tarp darbalaukių</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Pasirinkite darbalaukį iš kurio kopijuoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Pasirinkite, norėdami, kad failai būtų tik nukopijuoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Tik kopijuoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Pasirinkite darbalaukį į kurį kopijuoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Kopijuoti į:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Kopijuoti iš:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Pasirinkite, norėdami nukopijuoti, o tuomet ištrinti skirtumus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Sinchronizuoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Pasirinkite, norėdami kopijuoti/sinchronizuoti Bendrą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Bendrą aplanką</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Pasirinkite, norėdami kopijuoti/sinchronizuoti visą namų katalogą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Visą namų katalogą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Pasirinkite, norėdami kopijuoti/sinchronizuoti naršyklės konfigūraciją</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Firefox ar Iceweasel) konfigūracijas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Pasirinkite, norėdami kopijuoti/sinchronizuoti Dokumentus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>Dokumentų aplanką</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Ką kopijuoti/sinchronizuoti:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Eiga</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Pakeitimų būsena</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Būsena:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Pakeitimų eiga</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Pridėti/Šalinti grupes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Pridėti grupę</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>grupės_pavadinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Grupės pavadinimas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Ištrinti grupę</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Atsisakyti bet kokių pakeitimų, o tuomet išeiti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Rodyti žinyną</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Taikyti bet kokius pakeitimus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Taikyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>Apie šią programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>Apie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <location filename="../mainwindow.cpp" line="148"/>
        <location filename="../mainwindow.cpp" line="156"/>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="689"/>
        <location filename="../mainwindow.cpp" line="716"/>
        <location filename="../mainwindow.cpp" line="864"/>
        <location filename="../mainwindow.cpp" line="965"/>
        <location filename="../mainwindow.cpp" line="971"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <location filename="../mainwindow.cpp" line="979"/>
        <location filename="../mainwindow.cpp" line="981"/>
        <source>none</source>
        <translation>nėra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <location filename="../mainwindow.cpp" line="652"/>
        <location filename="../mainwindow.cpp" line="870"/>
        <location filename="../mainwindow.cpp" line="878"/>
        <source>browse...</source>
        <translation>naršyti...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Naudotojo konfigūracija bus pataisyta. Dabar, prašome užverti visas kitas programas. Užbaigus, prašome atsijungti arba paleisti kompiuterį iš naujo. Ar tikrai norite pataisyti dabar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="221"/>
        <source>User group membership was restored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Mozilla settings were reset.</source>
        <translation>Mozilla nustatymai buvo atstatyti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Autologin options</source>
        <translation>Automatinio prisijungimo parametrai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Automatinis prisijungimas paskyrai &quot;%1&quot; išjungtas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Automatinis prisijungimas paskyrai &quot;%1&quot; įjungtas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Privalote nurodyti &quot;Kopijuoti į&quot; paskirties vietą. Negalite kopijuoti į darbalaukį, prie kurio esate prisijungę.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Prieš kopijuojant, užverkite visas kitas programas. Įsitikinkite, kad kopijavimo paskirties vieta yra pakankamai didelė, kad joje tilptų kopijuojami failai. Kopijavimas tarp darbalaukių gali perrašyti ar ištrinti jūsų failus ar nuostatas paskirties darbalaukyje. Ar tikrai norite tęsti?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Synchronizing desktop...</source>
        <translation>Sinchronizuojamas darbalaukis...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Copying desktop...</source>
        <translation>Kopijuojamas darbalaukis...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Naudotojo vardas privalo būti bent 2 simbolių ilgio. Prašome prieš tęsiant, pasirinkti ilgesnį vardą.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Atleiskite, šis vardas jau yra naudojamas. Pasirinkite kitą vardą.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Slaptažodžio įrašai nesutampa. Prašome bandyti dar kartą.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Slaptažodis turi būti bent 2 simbolių ilgio. Prieš tęsdami, įveskite ilgesnį slaptažodį.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>The user was added ok.</source>
        <translation>Naudotojas buvo sėkmingai pridėtas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Failed to add the user.</source>
        <translation>Nepavyko pridėti naudotojo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Password successfully changed.</source>
        <translation>Slaptažodis sėkmingai pakeistas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Failed to change password.</source>
        <translation>Nepavyko pakeisti slaptažodžio.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Šio veiksmo negalima bus atšaukti. Ar tikrai norite ištrinti naudotoją %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>The user has been deleted.</source>
        <translation>Naudotojas buvo ištrintas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Failed to delete the user.</source>
        <translation>Nepavyko ištrinti naudotojo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>The system group was added ok.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Failed to add the system group.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="469"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Šio veiksmo neįmanoma bus atšaukti. Ar tikrai norite ištrinti grupę %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Failed to delete the group.</source>
        <translation>Nepavyko ištrinti grupės.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Group: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The group has been deleted.</source>
        <translation>Grupė buvo ištrinta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The groups have been deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>The changes have been applied.</source>
        <translation>Pakeitimai buvo pritaikyti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Failed to apply group changes</source>
        <translation>Nepavyko pritaikyti grupės pakeitimų</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>The selected user name is currently in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>The user was renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <location filename="../mainwindow.cpp" line="606"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sinchronizuojamas darbalaukis...gerai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>Copying desktop...ok</source>
        <translation>Kopijuojamas darbalaukis...gerai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sinchronizuojamas darbalaukis...nepavyko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Copying desktop...failed</source>
        <translation>Kopijuojamas darbalaukis...nepavyko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Confirmation</source>
        <translation>Patvirtinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="631"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>About %1</source>
        <translation>Apie %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Paprastas naudotojų konfigūravimas, skirtas MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorių teisės (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>%1 License</source>
        <translation>%1 licencija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="855"/>
        <source>%1 Help</source>
        <translation>%1 žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Select folder to copy to</source>
        <translation>Pasirinkite aplanką į kurį kopijuoti</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Keitinių žurnalas</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
